%define major                   28
%define libname                 %mklibname prelude %{major}
%define cppmajor                12
%define libcpp                  %mklibname preludecpp %{cppmajor}
%define libnamedevel            %mklibname prelude -d

%bcond_without ruby

Name:           libprelude
Version:        5.2.0
Release:        %mkrel 15
Summary:        Prelude SIEM Library
License:        LGPLv2+
Group:          System/Libraries
URL:            https://www.prelude-siem.org/
Source0:        https://www.prelude-siem.org/pkg/src/%{version}/%{name}-%{version}.tar.gz
# https://www.prelude-siem.org/issues/859
Patch0:         libprelude-4.0.0-linking.patch
# https://www.prelude-siem.org/issues/860
Patch1:         libprelude-4.0.0-ruby_vendorarchdir.patch
# https://www.prelude-siem.org/issues/862
Patch2:         libprelude-4.0.0-gnutls_priority_set_direct.patch
# https://www.prelude-siem.org/issues/863
Patch3:         libprelude-4.0.0-fsf_address.patch
# https://www.prelude-siem.org/issues/865
Patch4:         libprelude-4.0.0-fix_timegm.patch
# https://www.prelude-siem.org/issues/887
Patch5:         libprelude-4.0.0-fix_prelude_tests_timer.patch
# https://github.com/swig/swig/issues/1689
# https://github.com/swig/swig/pull/1692
# For now, add a minimum patch to support ruby2.7
Patch13:        libprelude-5.1.1-ruby27.patch
# Fix build with python3.9
Patch14:	libprelude-python3.9.patch
Patch15:	libprelude-configure-c99.patch
Patch16:	libprelude-c99.patch
BuildRequires:  bison
BuildRequires:  chrpath
BuildRequires:  flex
BuildRequires:  swig
BuildRequires:  libgcrypt-devel
BuildRequires:  libgpg-error-devel
BuildRequires:  libltdl-devel
BuildRequires:  perl-devel
BuildRequires:  pkgconfig(gnutls)
BuildRequires:  pkgconfig(lua) >= 5.2
BuildRequires:  pkgconfig(python3)
%if %{with ruby}
BuildRequires:  pkgconfig(ruby)
%endif
BuildRequires:  pkgconfig(zlib)

%description
The Prelude Library is a collection of generic functions providing
communication between the Prelude SIEM suite components. It
provides a convenient interface for sending alerts to Prelude
Manager with transparent SSL, failover and replication support,
asynchronous events and timer interfaces, an abstracted
configuration API (hooking at the commandline, the configuration
line, or wide configuration, available from the Manager), and a
generic plugin API. It allows you to easily turn your favorite
security program into a Prelude sensor.

%package -n %{libname}
Summary:        Prelude SIEM Library
Group:          System/Libraries
Provides:       %{name} = %{version}-%{release}

%description -n %{libname}
The Prelude Library is a collection of generic functions providing
communication between the Prelude SIEM suite components. It
provides a convenient interface for sending alerts to Prelude
Manager with transparent SSL, failover and replication support,
asynchronous events and timer interfaces, an abstracted
configuration API (hooking at the commandline, the configuration
line, or wide configuration, available from the Manager), and a
generic plugin API. It allows you to easily turn your favorite
security program into a Prelude sensor.

%package -n %{libcpp}
Summary:        Prelude SIEM Library
Group:          System/Libraries

%description -n %{libcpp}
The Prelude Library is a collection of generic functions providing
communication between the Prelude SIEM suite components. It
provides a convenient interface for sending alerts to Prelude
Manager with transparent SSL, failover and replication support,
asynchronous events and timer interfaces, an abstracted
configuration API (hooking at the command line, the configuration
line, or wide configuration, available from the Manager), and a
generic plugin API. It allows you to easily turn your favorite
security program into a Prelude sensor.

%package -n %{libnamedevel}
Summary:        Libraries, includes, etc. for developing Prelude IDS sensors
Group:          Development/C
Requires:       %{libname} = %{version}-%{release}
Requires:       %{libcpp} = %{version}-%{release}
Requires:       libltdl-devel
Provides:       %{name}-devel = %{version}-%{release}
Provides:       prelude-devel = %{version}-%{release}

%description -n %{libnamedevel}
Libraries, include files, etc you can use to develop Prelude IDS
sensors using the Prelude Library. The Prelude Library is a
collection of generic functions providing communication between
the Prelude SIEM suite components. It provides a convenient
interface for sending alerts to Prelude Manager with transparent
SSL, failover and replication support, asynchronous events and
timer interfaces, an abstracted configuration API (hooking at the
command line, the configuration line, or wide configuration,
available from the Manager), and a generic plugin API. It allows
you to easily turn your favorite security program into a Prelude
sensor.

%package -n prelude-tools
Summary:        The interface for %{libname}
Group:          Networking/Other
Requires:       %{libname} = %{version}-%{release}

%description -n prelude-tools
Provides a convenient interface for sending alerts to Prelude
Manager.

%package -n python3-prelude
Summary:        Python 3 bindings for prelude
Group:          Development/Python
Requires:       %{libname} = %{version}-%{release}
%{?python_provide:%python_provide python3-prelude}

%description -n python3-prelude
Provides python 3 bindings for prelude.

%package -n perl-prelude
Summary:        Perl bindings for prelude
Group:          Development/Perl
Requires:       %{libname} = %{version}-%{release}

%description -n perl-prelude
Provides perl bindings for prelude.

%package -n ruby-prelude
Summary:        Ruby bindings for prelude
Group:          Development/Ruby
Requires:       %{libname} = %{version}-%{release}

%description -n ruby-prelude
Provides ruby bindings for prelude.

%package -n lua-prelude
Summary:        Lua bindings for prelude
Group:          Development/Other
Requires:       %{libname} = %{version}-%{release}
Requires:       lua%{lua_version}

%description -n lua-prelude
Provides Lua bindings for prelude generated by SWIG.

%prep
%autosetup -p1

# force swig to rebuild files
for i in $(find . -name "*.i"); do
  touch $i
done

%build
export CFLAGS="%{optflags} -pthread"
export CXXFLAGS="$CFLAGS"
%configure \
    --without-included-ltdl \
    --disable-static \
    --enable-shared \
    --with-swig \
    --without-python2 \
    --with-python3 \
    --with-perl-installdirs=vendor \
    --without-included-regex \
    --includedir=%{_includedir}/%{name} \
    --disable-rpath \

%make_build

%install
%make_install

chmod 755 %{buildroot}%{_libdir}/perl5/vendor_perl/auto/Prelude/Prelude.so
chrpath -d %{buildroot}%{_libdir}/perl5/vendor_perl/auto/Prelude/Prelude.so

find %{buildroot} -name '*.la' -delete

%files -n %{libname}
%doc AUTHORS ChangeLog README NEWS
%license COPYING LICENSE.README HACKING.README
%{_libdir}/libprelude.so.%{major}
%{_libdir}/libprelude.so.%{major}.*

%files -n %{libcpp}
%{_libdir}/libpreludecpp.so.%{cppmajor}
%{_libdir}/libpreludecpp.so.%{cppmajor}.*

%files -n %{libnamedevel}
%doc %{_datadir}/gtk-doc/html/libprelude/
%{_datadir}/%{name}/swig
%{_bindir}/%{name}-config
%{_libdir}/*.so
%{_libdir}/pkgconfig/*.pc
%{_includedir}/%{name}/
%{_datadir}/aclocal/*.m4
%{_mandir}/man1/%{name}-config.1*

%files -n prelude-tools
%doc AUTHORS ChangeLog README INSTALL
%{_bindir}/prelude-adduser
%{_bindir}/prelude-admin
%{_mandir}/man1/prelude-admin.1*
%dir %{_sysconfdir}/prelude
%dir %{_sysconfdir}/prelude/default
%dir %{_sysconfdir}/prelude/profile
%attr(0644,root,root) %config(noreplace) %{_sysconfdir}/prelude/default/*.conf
%dir %{_var}/spool/prelude

%files -n python3-prelude
%{python3_sitearch}/*

%files -n perl-prelude
%{perl_vendorarch}/*.pm
%{perl_vendorarch}/auto/Prelude

%if %{with ruby}
%files -n ruby-prelude
%{ruby_vendorarchdir}/Prelude.so
%endif

%files -n lua-prelude
%{lua_libdir}/prelude.so


%changelog
* Wed Dec 04 2024 pterjan <pterjan> 5.2.0-15.mga10
+ Revision: 2120953
- Rebuild for Ruby 3.3

* Fri Aug 23 2024 tv <tv> 5.2.0-14.mga10
+ Revision: 2089682
- Rebuild for perl-5.40

* Sat May 11 2024 daviddavid <daviddavid> 5.2.0-13.mga10
+ Revision: 2063744
- add fedora patches to fix build with GCC 14

* Thu Dec 28 2023 daviddavid <daviddavid> 5.2.0-12.mga10
+ Revision: 2022744
- rebuild for py3.12

* Tue Dec 05 2023 daviddavid <daviddavid> 5.2.0-11.mga10
+ Revision: 2013189
- rebuild for new perl 5.38.0

* Thu Aug 04 2022 tv <tv> 5.2.0-10.mga9
+ Revision: 1875253
- Fix rpath
- Rebuild for perl-5.36
+ umeabot <umeabot>
- Rebuild for Perl 5.36
- Mageia 9 Mass Rebuild
+ pterjan <pterjan>
- Rebuild for Ruby 3.1

* Mon May 24 2021 umeabot <umeabot> 5.2.0-6.mga9
+ Revision: 1726371
- Rebuild for perl 5.34

* Sat Apr 03 2021 wally <wally> 5.2.0-5.mga9
+ Revision: 1712948
- rebuild for lua 5.4

* Mon Mar 29 2021 wally <wally> 5.2.0-4.mga9
+ Revision: 1711800
- fix lua requires

* Sat Mar 27 2021 wally <wally> 5.2.0-3.mga9
+ Revision: 1710948
- update python patch

* Sat Mar 27 2021 daviddavid <daviddavid> 5.2.0-2.mga9
+ Revision: 1710934
- rebuild for python 3.9

* Fri Sep 18 2020 daviddavid <daviddavid> 5.2.0-1.mga8
+ Revision: 1628532
- new version: 5.2.0

* Wed Jun 17 2020 umeabot <umeabot> 5.1.1-4.mga8
+ Revision: 1594220
- Rebuild for perl 5.32

* Tue Mar 03 2020 daviddavid <daviddavid> 5.1.1-3.mga8
+ Revision: 1553366
- add a minimum patch to support ruby 2.7
+ pterjan <pterjan>
- Rebuild for ruby 2.7

* Mon Feb 17 2020 umeabot <umeabot> 5.1.1-2.mga8
+ Revision: 1537297
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%configure2_5x

* Tue Oct 29 2019 daviddavid <daviddavid> 5.1.1-1.mga8
+ Revision: 1456470
- new version: 5.1.1

* Sun Oct 20 2019 daviddavid <daviddavid> 5.1.0-1.mga8
+ Revision: 1454760
- new version: 5.1.0

* Wed Sep 11 2019 wally <wally> 5.0.0-4.mga8
+ Revision: 1439631
- rebuild for python3.8
- drop python2 support
- drop multiarch support

* Tue Aug 27 2019 daviddavid <daviddavid> 5.0.0-3.mga8
+ Revision: 1434416
- really rebuild for perl 5.30

* Tue Aug 27 2019 daviddavid <daviddavid> 5.0.0-2.mga8
+ Revision: 1434273
- add fedora patch to fix FTBFS with awk 5
- add fedora patch to Fix FTBFS with Python 3.8
+ tmb <tmb>
- rebuild for perl 5.30

* Sun Feb 24 2019 daviddavid <daviddavid> 5.0.0-1.mga7
+ Revision: 1369723
- new version: 5.0.0
- now libmajor is 28
- remove merged upstream patches

* Tue Jan 08 2019 daviddavid <daviddavid> 4.1.0-4.mga7
+ Revision: 1352388
- rebuild for new Python 3.7

* Thu Sep 27 2018 daviddavid <daviddavid> 4.1.0-3.mga7
+ Revision: 1307665
- add two upstream patches to fix FTBFS
+ umeabot <umeabot>
- Mageia 7 Mass Rebuild

* Tue Aug 07 2018 daviddavid <daviddavid> 4.1.0-2.mga7
+ Revision: 1248457
- rebuild for new perl 5.28.0

* Sat Jan 13 2018 daviddavid <daviddavid> 4.1.0-1.mga7
+ Revision: 1192635
- new version: 4.1.0

* Mon Jan 01 2018 pterjan <pterjan> 4.0.0-2.mga7
+ Revision: 1188461
- Rebuild for Ruby 2.5

* Sat Sep 23 2017 daviddavid <daviddavid> 4.0.0-1.mga7
+ Revision: 1157800
- new version: 4.0.0
- sync patches with fedora
- update Summary and description
- rename python-prelude to python2-prelude
+ tv <tv>
- fix build with new ruby
+ pterjan <pterjan>
- Rebuild for perl ABI changes
- Rebuild for new Ruby

* Fri Aug 04 2017 daviddavid <daviddavid> 3.1.0-4.mga7
+ Revision: 1134775
- rebuild for Python 3.6
+ wally <wally>
- don't re-generate gtk-docs and install them to standard location

* Sun Jul 23 2017 wally <wally> 3.1.0-3.mga7
+ Revision: 1129473
- fix perl binding build
+ neoclust <neoclust>
- Rebuild against new Perl 5.26

* Sun Oct 16 2016 wally <wally> 3.1.0-2.mga6
+ Revision: 1061116
- add patch to fix perl binding underlinking

* Sat Oct 15 2016 daviddavid <daviddavid> 3.1.0-1.mga6
+ Revision: 1060909
- new version: 3.1.0 (mga#19451)
- enable lua support
- disable unwanted static libraries
- update BRs list

* Sat Jun 18 2016 pterjan <pterjan> 1.2.6-5.mga6
+ Revision: 1022153
- Rebuild for perl 5.22.2

* Mon Jan 11 2016 luigiwalser <luigiwalser> 1.2.6-4.mga6
+ Revision: 921820
- rebuild for gnutls
+ philippem <philippem>
- remove twice added with-swig

* Sat Dec 05 2015 philippem <philippem> 1.2.6-3.mga6
+ Revision: 908402
- build with our patched swig, provide ruby bindings files
+ pterjan <pterjan>
- Force regeneration of swig binding
+ tv <tv>
- rebuild for python 3.5
+ spuhler <spuhler>
- rebuild with python-3.5

* Thu Sep 10 2015 fwang <fwang> 1.2.6-1.mga6
+ Revision: 875506
- update file list
- add python3 sub package
- update file list
- update libmajor and enable ruby
- 1.2.6
- rebuild for new libgcrypt

* Sat Jun 27 2015 tv <tv> 1.0.1-18.mga6
+ Revision: 846149
- rebuild with soname-ified perl

* Wed Jun 24 2015 sander85 <sander85> 1.0.1-17.mga6
+ Revision: 841776
- Rebuild for perl 5.22

* Wed Oct 15 2014 umeabot <umeabot> 1.0.1-16.mga5
+ Revision: 744205
- Second Mageia 5 Mass Rebuild

* Sat Sep 27 2014 tv <tv> 1.0.1-15.mga5
+ Revision: 726835
- rebuild for missing pythoneggs deps

* Tue Sep 16 2014 umeabot <umeabot> 1.0.1-14.mga5
+ Revision: 681718
- Mageia 5 Mass Rebuild

* Sat Jul 05 2014 pterjan <pterjan> 1.0.1-13.mga5
+ Revision: 643921
- Fix build with perl 5.20
- Rebuild for perl 5.20
+ spuhler <spuhler>
- rebuild against perl-5.20
+ jquelin <jquelin>
- perl 5.20.0 rebuild

* Sat May 31 2014 pterjan <pterjan> 1.0.1-9.mga5
+ Revision: 628304
- Rebuild for new Python

* Tue Oct 22 2013 umeabot <umeabot> 1.0.1-8.mga4
+ Revision: 542694
- Mageia 4 Mass Rebuild

* Mon Oct 14 2013 pterjan <pterjan> 1.0.1-7.mga4
+ Revision: 497868
- Rebuild to add different pythonegg provides for python 2 and 3

* Sat Sep 21 2013 fwang <fwang> 1.0.1-6.mga4
+ Revision: 482868
- rebuild for ruby 2.0

* Wed May 29 2013 fwang <fwang> 1.0.1-5.mga4
+ Revision: 430415
- rebuild for new perl

* Sat Jan 12 2013 umeabot <umeabot> 1.0.1-4.mga3
+ Revision: 357992
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Thu Jan 10 2013 fwang <fwang> 1.0.1-3.mga3
+ Revision: 344596
- update file list
- update file list

* Thu Nov 01 2012 fwang <fwang> 1.0.1-2.mga3
+ Revision: 312002
- add patch from pld-linux to build with ruby 1.9
- rebuild for new ruby

* Sun Sep 02 2012 fwang <fwang> 1.0.1-1.mga3
+ Revision: 287174
- update file list
- add fedora patch to build with glibc
- fix build with latest gcc
- new version 1.0.1

* Fri Jun 01 2012 pterjan <pterjan> 1.0.0-10.mga3
+ Revision: 252600
- Better fix for python binding now that swig is updated

* Fri Jun 01 2012 pterjan <pterjan> 1.0.0-9.mga3
+ Revision: 252588
- BuildRequires swig as I am patching the interface file
- Fix build of python binding
- Fix build with new gnutls
+ fwang <fwang>
- rebuild for new perl
+ jquelin <jquelin>
- perl 5.16 rebuild

* Tue Aug 02 2011 fwang <fwang> 1.0.0-6.mga2
+ Revision: 131392
- rebuild for new gnutls

* Sun Jun 12 2011 ahmad <ahmad> 1.0.0-5.mga2
+ Revision: 104504
- Rebuild for perl-5.14.0

* Mon Feb 21 2011 ahmad <ahmad> 1.0.0-4.mga1
+ Revision: 55726
- rebuild to make all pythonegg requires/provides lowercase

* Wed Jan 19 2011 jquelin <jquelin> 1.0.0-3.mga1
+ Revision: 23790
- rebuild

* Mon Jan 17 2011 pterjan <pterjan> 1.0.0-2.mga1
+ Revision: 21359
- Rebuild for python 2.7

* Sat Jan 15 2011 blino <blino> 1.0.0-1.mga1
+ Revision: 19272
- add patch from OpenEmbbeded to fix build with libtool 2.4
+ ahmad <ahmad>
- drop unneeded scriptlets
+ pterjan <pterjan>
- imported package libprelude

